# main.py: ThingSpeak_Climate_Station
# ESP32
# Baro: BMP180, Thermo: 2x DS18x20, Hygro: DHT11, 
# display: SSD1306

import network
import urequests

from machine import Pin, I2C
import ssd1306
import dht 
from time import sleep
from bmp180 import BMP180

# i2c pin assignmet
i2c = I2C(-1, scl=Pin(22), sda=Pin(21))

import esp
esp.osdebug(None)

import gc
gc.collect()

# baro initialization BMP180
bmp = BMP180(i2c)
bmp.oversample = 2
bmp.sealevel = 101325

# hygro initialization DHT11
sensor = dht.DHT11(Pin(14))
DHT_cal = 1

# OLED dimensions and initialization SSD1306
oled_width = 128
oled_height = 64
oled = ssd1306.SSD1306_I2C(oled_width, oled_height, i2c)
d1 = 60 # column distance 1
d2 = 90 # column distance 1
h1 = 9  # line hight

ssid = 'FRITZ!Box 7412'
password = '57912120423522963495'

api_key = 'TCLH688I7MJIHNZX'

station = network.WLAN(network.STA_IF)
station.active(True)
station.connect(ssid, password)

while station.isconnected() == False:
  pass

print('Connection successful')
print(station.ifconfig())

while True:

  oled.fill(0)
  oled.text('Climate Station', 0, 0)

  # DHT11: Temp & Humiture
  sensor.measure()
  temp_DHT11 = sensor.temperature() + DHT_cal
  hum_DHT11 = sensor.humidity()
  print('Temp1: %3.1f C' %temp_DHT11)
  print('Humi : %3.1f %%' %hum_DHT11)
  temperature_string_DHT11 = str(int(10*temp_DHT11)/10)
  humidity_string_DHT11 = str(int(10*hum_DHT11)/10)
  oled.text('Temp1:', 0 ,h1)
  oled.text(temperature_string_DHT11, d1 ,h1)

  oled.text(' C', d2 ,h1)
  oled.text('Humi :', 0 , 2*h1)
  oled.text(humidity_string_DHT11, d1 ,2*h1)
  oled.text(' %', d2 ,2*h1)
    
  # BMP180: Temp & pressure
  temp_BMP180 = bmp.temperature
  pres_BMP180 = int(bmp.pressure/100)
  print('Temp2: %3.1f C' %temp_BMP180)
  print('Baro : %3.0f hPa' %pres_BMP180)
  temperature_string_BMP180 = str(int(10*temp_BMP180)/10)
  pressure_string_BMP180 = str(pres_BMP180)
  oled.text('Temp2:', 0 ,3*h1)
  oled.text(temperature_string_BMP180, d1 ,3*h1)
  oled.text(' C', d2 ,3*h1)
  oled.text('Baro :', 0 ,4*h1)
  oled.text(pressure_string_BMP180, d1 ,4*h1)
  oled.text(' hPa', d2 ,4*h1)
  
  print()
  oled.show()
  sleep(1)

  sensor_readings = {'field1':temperature_string_DHT11, 'field2':humidity_string_DHT11, 'field3':temperature_string_BMP180, 'field4':pressure_string_BMP180}

  print(sensor_readings)

  request_headers = {'Content-Type': 'application/json'}

  request = urequests.post(
  'http://api.thingspeak.com/update?api_key=' + api_key,
  json=sensor_readings,
  headers=request_headers)
  print(request.text)

  request.close()
  
  sleep(15)



